@@ -6,6 +6,8 @@ from glob import glob
 import argparse
 from pprint import pprint
 from jinja2 import FileSystemLoader, Environment, TemplateNotFound, FunctionLoader
+from collections import OrderedDict
+
 
 class HumeRenderer():
     def __init__(self,templates_dir=None, transfer_method=None, debug=False):
@@ -71,6 +73,23 @@ class HumeRenderer():
         }
       ]
     },
+{% if hume.extra.items()|count > 0 %}
+    {
+      "type": "section",
+      "text": {
+        "type": "mrkdwn",
+        "text": "*Extra fields:*\n"
+      },
+      "fields": [
+      {% for key, value in hume.extra.items() %}
+        {
+          "type": "mrkdwn",
+          "text": "*{{ key }}:*\n{{ value }}"
+        },
+      {% endfor %}
+      ]
+    },
+{% endif %}
     {
         "type": "divider"
     },
@@ -115,6 +134,9 @@ class HumeRenderer():
         options.append('default_{}.tpl'.format(level))
         options.append('default_default.tpl')
 
+        # base_template might be 'default'. I prefer this to avoid dups:
+        options = list(OrderedDict.fromkeys(options))
+
 
         # Try each template option in order of priority. Return ASAP.
         # If no template option exists, use another loader
